# Customize vcpkg toolchains

This folder applies to the custom vcpkg toolchains. These toolchains can be loaded automatically which can be copied from the `scripts/toolchains` folder of the vcpkg repository or created from scratch.
